@@ -1,5 +1,5 @@
 /* Pango
- * itemize.c:
+ * mapping.c:
  *
  * Copyright (C) 1999 Red Hat Software
  *
@@ -30,7 +30,7 @@
  * cursor positioning is allowed within clusters or not.
  */
 
-#include <pango/pango-glyph.h>
+#include "pango-glyph.h"
 
 /**
  * pango_glyph_string_index_to_x:
@@ -272,7 +272,7 @@ pango_glyph_string_x_to_index (PangoGlyphString *glyphs,
       if (index)
 	*index = start_index;
       if (trailing)
-	trailing = 0;
+	*trailing = 0;
     }
   else
     {
